@@ -62,7 +62,7 @@ class TornadoAngularServer(Server):
 
     def get_api_handlers(self):
         return [
-            ('bla/?', VersionHandler),
+            ('version/?', VersionHandler),
         ]
 
     def get_web_prefix(self):
@@ -149,10 +149,7 @@ class TornadoAngularServer(Server):
         return Config
 
     def get_web_allowed_config(self):
-        return [
-            'ANGULAR_ROOT',
-            'FOO',
-        ]
+        return []
 
     def get_api_plugins(self):
         return []
